@@ -54,11 +54,11 @@ class DataFrame:
         df = DataFrame.to_pandas(self.head())
         return df.__str__()
     def __getattr__(self, key):        
-        if type(key) == int:
+        if (type(key) == int or type(key) == np.int64):
             key = list(self.__d__.keys())[key]
         return self.__d__[key]
     def __setattr__(self, name, value):
-        if type(name) == int:
+        if (type(name) == int or type(name) == np.int64):
             name = list(self.__d__.keys())[name]
         if type(value) == dict:
             raise Exception("Cannot insert a dictionary")            
@@ -80,7 +80,7 @@ class DataFrame:
     def __getitem__(self,args):
         if type(args) == tuple:
             rows,key=args
-            if type(rows) == int:
+            if (type(rows) == int or type(rows) == np.int64):
                 rows = [rows]
             if type(key) == slice:
                 
@@ -104,11 +104,11 @@ class DataFrame:
                     if type(key) == list or type(key) == np.array or type(key) == range:                    
                             t_ = DataFrame()
                             for k in key:
-                                if type(k) == int:
+                                if (type(k) == int or type(k) == np.int64):
                                     k = list(self.__d__.keys())[k]
                                 DataFrame.__setattr__(t_,k,self.__d__[k][rows])
                             return t_
-                    elif type(key) == int:
+                    elif (type(key) == int or type(key) == np.int64):
                         k = list(self.__d__.keys())[key]
                         return self.__d__[k][rows]
         else:
@@ -134,20 +134,20 @@ class DataFrame:
                     if type(key) == list or type(key) == np.array or type(key) == range:                    
                             t_ = DataFrame()
                             for k in key:
-                                if type(k) == int:
+                                if (type(k) == int or type(k) == np.int64):
                                     k = list(self.__d__.keys())[k]
                                 DataFrame.__setattr__(t_,k,self.__d__[k])
                             return t_
-                    elif type(key) == int:
+                    elif (type(key) == int or type(key) == np.int64):
                         k = list(self.__d__.keys())[key]
                         return self.__d__[k]
     def __setitem__(self,args,values):
         if type(args) == tuple:
             rows,key = args
-            if type(rows) == int:
+            if (type(rows) == int or type(rows) == np.int64):
                 rows = [rows]
-            if type(key) == str or type(key) == int:
-                if type(key) == int:
+            if type(key) == str or (type(key) == int or type(key) == np.int64):
+                if (type(key) == int or type(key) == np.int64):
                     key = list(self.__d__.keys())[key]
                 self.__d__[key][rows] = values
             else:
@@ -169,20 +169,20 @@ class DataFrame:
                 else:
                     if len(key) == 1:                    
                         for k in key:
-                            if type(k) == int:
+                            if (type(k) == int or type(k) == np.int64):
                                 k = list(self.__d__.keys())[k]
                             self.__d__[k][rows] = values
                     else:
                         raise Exception("Cannot only set 1 column at the moment.")
         else:
-            if type(args) == str or type(args) == int:
-                if type(args) == int:
+            if type(args) == str or (type(args) == int or type(args) == np.int64):
+                if (type(args) == int or type(args) == np.int64):
                     key = list(self.__d__.keys())[args]
                 DataFrame.__setattr__(self,args,values)
             else:
                 if len(args) == 1:
                     for k in args:
-                        if type(k) == int:
+                        if (type(k) == int or type(k) == np.int64):
                             k = list(self.__d__.keys())[k]
                         self.__d__[k] = values
                 else:
@@ -212,15 +212,15 @@ class DataFrame:
     def rename(self,keys,new_keys):
         self.__stop_appending__()        
         new_d = {}
-        if type(keys) == str or type(keys) == int:
-            if type(keys) == int:
+        if type(keys) == str or (type(keys) == int or type(keys) == np.int64):
+            if (type(keys) == int or type(keys) == np.int64):
                 keys = [self.columns[keys]]
             else:
                 keys = [keys]
         else:
             keys_ = []
             for k in keys:
-                if type(k) == int:
+                if (type(k) == int or type(k) == np.int64):
                     k = self.columns[k]
                 keys_.append(k)
             keys = keys_
@@ -263,6 +263,7 @@ class DataFrame:
         self.__stop_appending__()
         order = np.argsort(self.__d__[name])
         self.sort(order)
+        return self
     def __temp_sort_by_column__(self,name):
         self.__stop_appending__()
         order = np.argsort(self.__d__[name])
@@ -300,7 +301,7 @@ class DataFrame:
         val,groups = self.group_by(key)
         for column in columns:
             values.append([])
-            if type(column) == int:
+            if (type(column) == int or type(column) == np.int64):
                 name = list(self.__d__.keys())[column]
             else:
                 name = column            
@@ -372,7 +373,7 @@ class DataFrame:
         return np.array(result)
     def names(self):
         self.__stop_appending__()
-        super(DataFrame, self).__setattr__('columns', list(self.__d__.keys()))
+        super(DataFrame, self).__setattr__('columns', np.array(list(self.__d__.keys())))
         return self.columns
     
     def from_pandas(self,df):
